package net.buildbox.sd.textsaver;

import java.io.IOException;

import com.dropbox.sync.android.DbxAccountManager;
import com.dropbox.sync.android.DbxException;
import com.dropbox.sync.android.DbxFile;
import com.dropbox.sync.android.DbxFileSystem;
import com.dropbox.sync.android.DbxPath;

import android.support.v7.app.ActionBarActivity;
import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.EditText;
import android.widget.Toast;

public class MainActivity extends ActionBarActivity {

	private static final String APP_KEY = "b1hb7trnv9lc956";
	private static final String APP_SECRET = "je295gugvwecmrd";
	private static final int REQUEST_DROPBOX = 0;
	
	private static final String DROPBOX_FILENAME = "SaveText";
	
	private DbxAccountManager mAccountMgr = null;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		// Dropboxに接続
		mAccountMgr = DbxAccountManager
				.getInstance(getApplicationContext(), APP_KEY, APP_SECRET);
		// アカウントにアプリが接続しているかチェック
		if (!mAccountMgr.hasLinkedAccount()) {
			// アプリの接続開始
			mAccountMgr.startLink((Activity)this, REQUEST_DROPBOX);
		}
	}
	
	@Override
	protected void onResume() {
		super.onResume();
		
		// テキストの読み込み
		if (mAccountMgr.hasLinkedAccount()) {
			readSaveText();
		}
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		// Handle action bar item clicks here. The action bar will
		// automatically handle clicks on the Home/Up button, so long
		// as you specify a parent activity in AndroidManifest.xml.
		int id = item.getItemId();
		if (id == R.id.action_settings) {
			return true;
		}
		return super.onOptionsItemSelected(item);
	}
	
	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		if (requestCode == REQUEST_DROPBOX) {
			if (resultCode == Activity.RESULT_OK) {
				Toast.makeText(this, "Dropboxに接続しました。", Toast.LENGTH_SHORT).show();
			} else {
				Toast.makeText(this, "Dropboxに接続されませんでした。", Toast.LENGTH_SHORT).show();
			}
		}
		super.onActivityResult(requestCode, resultCode, data);
	}
	
	public void readSaveText() {
		DbxPath filePath = new DbxPath(DbxPath.ROOT, DROPBOX_FILENAME);
		
		try {
			// Dropboxの同期したファイルシステムを生成
			DbxFileSystem dbxFs = DbxFileSystem.forAccount(mAccountMgr.getLinkedAccount());

			// 最初の同期を待つ
			dbxFs.awaitFirstSync();
			
			// DROPBOX_FILENAMEのファイル存在チェック
			DbxFile dbxFile = null;
			EditText editSaveText = (EditText) findViewById(R.id.editSaveText);
			if (dbxFs.exists(filePath)) {
				// ファイルが存在した場合、テキストを読み込む
				dbxFile = dbxFs.open(filePath);
				try {
					editSaveText.setText(dbxFile.readString());
				} finally {
					dbxFile.close();
				}
			}
		} catch (DbxException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	public void onSaveEvent(View v) {
		DbxPath filePath = new DbxPath(DbxPath.ROOT, DROPBOX_FILENAME);
	
		try {
			// Dropboxの同期したファイルシステムを生成
			DbxFileSystem dbxFs = DbxFileSystem.forAccount(mAccountMgr.getLinkedAccount());
			
			// DROPBOX_FILENAMEのファイル存在チェック
			DbxFile dbxFile = null;
			EditText editSaveText = (EditText) findViewById(R.id.editSaveText);
			if (!dbxFs.exists(filePath)) {
				// 存在しない場合、ファイルを生成
				dbxFile = dbxFs.create(filePath);
			} else {
				// 存在した場合、ファイルを開く
				dbxFile = dbxFs.open(filePath);
			}
			try {
				// テキストの保存
				dbxFile.writeString(editSaveText.getText().toString());
				Toast.makeText(this, "テキストを保存しました", Toast.LENGTH_SHORT).show();
			} finally {
				dbxFile.close();
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}
